@@ -108,7 +108,7 @@ char *NETWORK_fields_text[] = {
     "datasize",
     "turbocellnid", "turbocellmode", "turbocellsat",
     "carrierset", "maxseenrate", "encodingset",
-    "decrypted", "dupeivpackets", 
+    "decrypted", "dupeivpackets", "bsstimestamp",
     NULL
 };
 
@@ -351,7 +351,7 @@ int Protocol_STATUS(PROTO_PARMS) {
 // The order of this is VERY IMPORTANT.  It HAS TO MATCH the order of the
 // char *[] array of fields.
 void Protocol_Network2Data(const wireless_network *net, NETWORK_data *data) {
-    char tmpstr[128];
+    char tmpstr[256];
 
     // Reserve fields
     data->ndvec.reserve(50);
@@ -361,10 +361,10 @@ void Protocol_Network2Data(const wireless_network *net, NETWORK_data *data) {
     snprintf(tmpstr, 128, "%d", (int) net->type);
     data->ndvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "\001%s\001", net->ssid.length() > 0 ? net->ssid.c_str() : " ");
+    snprintf(tmpstr, 255, "\001%s\001", net->ssid.length() > 0 ? net->ssid.c_str() : " ");
     data->ndvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "\001%s\001", net->beacon_info.length() > 0 ? net->beacon_info.c_str() : " ");
+    snprintf(tmpstr, 255, "\001%s\001", net->beacon_info.length() > 0 ? net->beacon_info.c_str() : " ");
     data->ndvec.push_back(tmpstr);
 
     snprintf(tmpstr, 128, "%d", net->llc_packets);
@@ -394,7 +394,7 @@ void Protocol_Network2Data(const wireless_network *net, NETWORK_data *data) {
     snprintf(tmpstr, 128, "%d", (int) net->ipdata.atype);
     data->ndvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "%hd.%hd.%hd.%hd",
+    snprintf(tmpstr, 128, "%hu.%hu.%hu.%hu",
              net->ipdata.range_ip[0], net->ipdata.range_ip[1],
              net->ipdata.range_ip[2], net->ipdata.range_ip[3]);
     data->ndvec.push_back(tmpstr);
@@ -515,6 +515,9 @@ void Protocol_Network2Data(const wireless_network *net, NETWORK_data *data) {
     snprintf(tmpstr, 128, "%d", net->dupeiv_packets);
     data->ndvec.push_back(tmpstr);
 
+    snprintf(tmpstr, 128, "%lld", net->bss_timestamp);
+    data->ndvec.push_back(tmpstr);
+
 }
 
 // Network records.  data = NETWORK_data
@@ -645,7 +648,7 @@ void Protocol_Client2Data(const wireless_network *net, const wireless_client *cl
     snprintf(tmpstr, 128, "%d", (int) cli->ipdata.atype);
     data->cdvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "%hd.%hd.%hd.%hd",
+    snprintf(tmpstr, 128, "%hu.%hu.%hu.%hu",
              cli->ipdata.ip[0], cli->ipdata.ip[1],
              cli->ipdata.ip[2], cli->ipdata.ip[3]);
     data->cdvec.push_back(tmpstr);
@@ -765,12 +768,12 @@ void Protocol_Packet2Data(const packet_info *info, PACKET_data *data) {
     snprintf(tmpstr, 128, "%d", (int) info->proto.type);
     data->pdvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "%hd.%hd.%hd.%hd",
+    snprintf(tmpstr, 128, "%hu.%hu.%hu.%hu",
              info->proto.source_ip[0], info->proto.source_ip[1],
              info->proto.source_ip[2], info->proto.source_ip[3]);
     data->pdvec.push_back(tmpstr);
 
-    snprintf(tmpstr, 128, "%hd.%hd.%hd.%hd",
+    snprintf(tmpstr, 128, "%hu.%hu.%hu.%hu",
              info->proto.dest_ip[0], info->proto.dest_ip[1],
              info->proto.dest_ip[2], info->proto.dest_ip[3]);
     data->pdvec.push_back(tmpstr);
